ib3 package
===========

Module contents
---------------

.. automodule:: ib3
    :members:
    :special-members: __init__
    :private-members:
    :show-inheritance:

Submodules
----------

ib3.auth module
---------------

.. automodule:: ib3.auth
    :members:
    :special-members: __init__
    :private-members:
    :show-inheritance:

ib3.connection module
---------------------

.. automodule:: ib3.connection
    :members:
    :special-members: __init__
    :private-members:
    :show-inheritance:


ib3.mixins module
---------------------

.. automodule:: ib3.mixins
    :members:
    :special-members: __init__
    :private-members:
    :show-inheritance:


ib3.nick module
---------------------

.. automodule:: ib3.nick
    :members:
    :special-members: __init__
    :private-members:
    :show-inheritance:
